@@ -1,12 +1,12 @@
-/* glpdmp.h (dynamic memory pools) */
+/* glpdmp.h (dynamic memory pool) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPDMP_H
