@@ -1,12 +1,12 @@
 /* glplib.h (miscellaneous low-level routines) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPLIB_H
@@ -32,6 +32,8 @@
 #define lib_init_env          glp_lib_init_env
 #define lib_env_ptr           glp_lib_env_ptr
 #define lib_free_env          glp_lib_free_env
+#define lib_open_hardcopy     glp_lib_open_hardcopy
+#define lib_close_hardcopy    glp_lib_close_hardcopy
 #define print                 glp_lib_print
 #define lib_set_print_hook    glp_lib_set_print_hook
 #define fault                 glp_lib_fault
@@ -47,6 +49,7 @@
 #define strspx                glp_lib_strspx
 #define strtrim               glp_lib_strtrim
 #define fp2rat                glp_lib_fp2rat
+#define write_bmp16           glp_lib_write_bmp16
 
 typedef struct LIBENV LIBENV;
 typedef struct LIBMEM LIBMEM;
@@ -87,6 +90,12 @@ struct LIBENV
       void *file_slot[LIB_MAX_OPEN]; /* FILE *file_slot[]; */
       /* file_slot[k], 0 <= k <= LIB_MAX_OPEN-1, is a pointer to k-th
          i/o stream; if k-th slot is free, file_slot[k] is NULL */
+#if 1 /* 14/I-2006 */
+      void *hcpy_file; /* FILE *hcpy_file; */
+      /* pointer to output stream used for hardcopying messages output
+         on the screen by the print and fault routines; NULL means the
+         hardcopy file is not used */
+#endif
 };
 
 struct LIBMEM
@@ -124,6 +133,12 @@ LIBENV *lib_env_ptr(void);
 int lib_free_env(void);
 /* free library environment */
 
+int lib_open_hardcopy(char *filename);
+/* open hardcopy file */
+
+int lib_close_hardcopy(void);
+/* close hardcopy file */
+
 void print(char *fmt, ...);
 /* print informative message */
 
@@ -185,6 +200,9 @@ char *strtrim(char *str);
 int fp2rat(double x, double eps, double *p, double *q);
 /* convert floating-point number to rational number */
 
+int write_bmp16(char *fname, int m, int n, char map[]);
+/* write 16-color raster image in Windows Bitmap format */
+
 #endif
 
 /* eof */
