@@ -1,12 +1,12 @@
 /* glplpx.h (LP/MIP problem object) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,15 +19,15 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPLPX_H
 #define _GLPLPX_H
 
 #include "glpavl.h"
-#include "glpinv.h"
+#include "glpbfi.h"
 #include "glpstr.h"
 
 #define lpx_create_prob       glp_lpx_create_prob
@@ -65,17 +65,6 @@
 #define lpx_put_ray_info      glp_lpx_put_ray_info
 #define lpx_put_ipt_soln      glp_lpx_put_ipt_soln
 #define lpx_put_mip_soln      glp_lpx_put_mip_soln
-#define lpx_check_name        glp_lpx_check_name         /* obsolete */
-#define lpx_set_obj_c0        glp_lpx_set_obj_c0         /* obsolete */
-#define lpx_set_row_coef      glp_lpx_set_row_coef       /* obsolete */
-#define lpx_set_col_coef      glp_lpx_set_col_coef       /* obsolete */
-#define lpx_load_mat          glp_lpx_load_mat           /* obsolete */
-#define lpx_load_mat3         glp_lpx_load_mat3          /* obsolete */
-#define lpx_unmark_all        glp_lpx_unmark_all         /* obsolete */
-#define lpx_mark_row          glp_lpx_mark_row           /* obsolete */
-#define lpx_mark_col          glp_lpx_mark_col           /* obsolete */
-#define lpx_clear_mat         glp_lpx_clear_mat          /* obsolete */
-#define lpx_del_items         glp_lpx_del_items          /* obsolete */
 
 #define lpx_get_prob_name     glp_lpx_get_prob_name
 #define lpx_get_class         glp_lpx_get_class
@@ -128,21 +117,8 @@
 #define lpx_mip_col_val       glp_lpx_mip_col_val
 #define lpx_get_row_bnds      glp_lpx_get_row_bnds       /* obsolete */
 #define lpx_get_col_bnds      glp_lpx_get_col_bnds       /* obsolete */
-#define lpx_get_obj_c0        glp_lpx_get_obj_c0         /* obsolete */
-#define lpx_get_row_coef      glp_lpx_get_row_coef       /* obsolete */
-#define lpx_get_col_coef      glp_lpx_get_col_coef       /* obsolete */
-#define lpx_get_row_mark      glp_lpx_get_row_mark       /* obsolete */
-#define lpx_get_col_mark      glp_lpx_get_col_mark       /* obsolete */
 #define lpx_get_row_info      glp_lpx_get_row_info       /* obsolete */
 #define lpx_get_col_info      glp_lpx_get_col_info       /* obsolete */
-#define lpx_get_ips_stat      glp_lpx_get_ips_stat       /* obsolete */
-#define lpx_get_ips_row       glp_lpx_get_ips_row        /* obsolete */
-#define lpx_get_ips_col       glp_lpx_get_ips_col        /* obsolete */
-#define lpx_get_ips_obj       glp_lpx_get_ips_obj        /* obsolete */
-#define lpx_get_mip_stat      glp_lpx_get_mip_stat       /* obsolete */
-#define lpx_get_mip_row       glp_lpx_get_mip_row        /* obsolete */
-#define lpx_get_mip_col       glp_lpx_get_mip_col        /* obsolete */
-#define lpx_get_mip_obj       glp_lpx_get_mip_obj        /* obsolete */
 
 #define lpx_reset_parms       glp_lpx_reset_parms
 #define lpx_set_int_parm      glp_lpx_set_int_parm
@@ -155,12 +131,15 @@
 
 #define lpx_std_basis         glp_lpx_std_basis
 #define lpx_adv_basis         glp_lpx_adv_basis
+#define lpx_cpx_basis         glp_lpx_cpx_basis
 
 #define lpx_simplex           glp_lpx_simplex
 #define lpx_check_kkt         glp_lpx_check_kkt
 #define lpx_interior          glp_lpx_interior
 #define lpx_integer           glp_lpx_integer
+#define lpx_check_int         glp_lpx_check_int
 #define lpx_intopt            glp_lpx_intopt
+#define lpx_primal            glp_lpx_primal
 
 #define lpx_invert            glp_lpx_invert
 #define lpx_ftran             glp_lpx_ftran
@@ -175,6 +154,20 @@
 #define lpx_prim_ratio_test   glp_lpx_prim_ratio_test
 #define lpx_dual_ratio_test   glp_lpx_dual_ratio_test
 
+#define lpx_remove_tiny       glp_lpx_remove_tiny
+#define lpx_reduce_form       glp_lpx_reduce_form
+#define lpx_eval_row          glp_lpx_eval_row
+#define lpx_eval_degrad       glp_lpx_eval_degrad
+#define lpx_gomory_cut        glp_lpx_gomory_cut
+#define lpx_cover_cut         glp_lpx_cover_cut
+
+#if 1 /* 19/IV-2006 */
+#define lpx_create_cog        glp_lpx_create_cog
+#define lpx_add_cog_edge      glp_lpx_add_cog_edge
+#define lpx_clique_cut        glp_lpx_clique_cut
+#define lpx_delete_cog        glp_lpx_delete_cog
+#endif
+
 #define lpx_read_mps          glp_lpx_read_mps
 #define lpx_write_mps         glp_lpx_write_mps
 #define lpx_read_bas          glp_lpx_read_bas
@@ -406,7 +399,7 @@ struct LPX
          basis[i] = k is the ordinal number of auxiliary (1 <= k <= m)
          or structural (m+1 <= k <= m+n) variable which corresponds to
          i-th basic variable xB[i], 1 <= i <= m */
-      INV *b_inv; /* INV b_inv[1:m,1:m]; */
+      BFI *b_inv; /* BFI b_inv[1:m,1:m]; */
       /* factorization (invertable form) of the current basis matrix;
          NULL means the factorization does not exist; it is valid only
          if the basis status is LPX_B_VALID */
@@ -567,6 +560,18 @@ struct LPX
       /* LP presolver option:
          0 - do not use LP presolver
          1 - use LP presolver */
+#if 1 /* 07/I-2006 */
+      int binarize; /* lpx_intopt */
+      /* if this flag is set, the routine lpx_intopt replaces integer
+         columns by binary ones */
+      int use_cuts; /* lpx_intopt */
+      /* if this flag is set, the routine lpx_intopt tries generating
+         cutting planes: */
+#define LPX_C_COVER     0x01  /* mixed cover cuts */
+#define LPX_C_CLIQUE    0x02  /* clique cuts */
+#define LPX_C_GOMORY    0x04  /* Gomory's mixed integer cuts */
+#define LPX_C_ALL       0xFF  /* all cuts */
+#endif
 };
 
 struct LPXROW
@@ -757,6 +762,8 @@ struct LPXAIJ
 #define LPX_K_MPSSKIP   325   /* lp->mps_skip */
 #define LPX_K_LPTORIG   326   /* lp->lpt_orig */
 #define LPX_K_PRESOL    327   /* lp->presol */
+#define LPX_K_BINARIZE  328   /* lp->binarize */
+#define LPX_K_USECUTS   329   /* lp->use_cuts */
 
 typedef struct LPXKKT LPXKKT;
 
@@ -927,7 +934,7 @@ int lpx_find_col(LPX *lp, char *name);
 void lpx_delete_index(LPX *lp);
 #endif
 
-void lpx_put_lp_basis(LPX *lp, int b_stat, int basis[], INV *b_inv);
+void lpx_put_lp_basis(LPX *lp, int b_stat, int basis[], BFI *b_inv);
 /* store LP basis information */
 
 void lpx_put_solution(LPX *lp, int p_stat, int d_stat,
@@ -946,40 +953,6 @@ void lpx_put_mip_soln(LPX *lp, int i_stat, double row_mipx[],
       double col_mipx[]);
 /* store mixed integer solution components */
 
-int lpx_check_name(char *name);
-/* check correctness of symbolic name */
-
-void lpx_set_obj_c0(LPX *lp, double c0);
-/* set (change) constant term of the obj. function */
-
-void lpx_set_row_coef(LPX *lp, int i, double coef);
-/* set (change) row objective coefficient */
-
-void lpx_set_col_coef(LPX *lp, int j, double coef);
-/* set (change) column objective coefficient */
-
-void lpx_load_mat(LPX *lp,
-      void *info, double (*mat)(void *info, int *i, int *j));
-/* load constraint matrix */
-
-void lpx_load_mat3(LPX *lp, int nz, int rn[], int cn[], double a[]);
-/* load constraint matrix */
-
-void lpx_unmark_all(LPX *lp);
-/* unmark all rows and columns */
-
-void lpx_mark_row(LPX *lp, int i, int mark);
-/* assign mark to row */
-
-void lpx_mark_col(LPX *lp, int j, int mark);
-/* assign mark to column */
-
-void lpx_clear_mat(LPX *lp);
-/* clear rows and columns of the constraint matrix */
-
-void lpx_del_items(LPX *lp);
-/* remove rows and columns from problem object */
-
 /* problem retrieving routines ---------------------------------------*/
 
 char *lpx_get_prob_name(LPX *lp);
@@ -1063,7 +1036,7 @@ int lpx_get_row_b_ind(LPX *lp, int i);
 int lpx_get_col_b_ind(LPX *lp, int j);
 /* retrieve column index in LP basis */
 
-INV *lpx_access_inv(LPX *lp);
+BFI *lpx_access_inv(LPX *lp);
 /* access factorization of basis matrix */
 
 int lpx_get_status(LPX *lp);
@@ -1137,21 +1110,6 @@ void lpx_get_col_bnds(LPX *lp, int j, int *typx, double *lb,
       double *ub);
 /* obtain column bounds */
 
-double lpx_get_obj_c0(LPX *lp);
-/* obtain constant term of the obj. function */
-
-double lpx_get_row_coef(LPX *lp, int i);
-/* obtain row objective coefficient */
-
-double lpx_get_col_coef(LPX *lp, int j);
-/* obtain column objective coefficient */
-
-int lpx_get_row_mark(LPX *lp, int i);
-/* determine row mark */
-
-int lpx_get_col_mark(LPX *lp, int j);
-/* determine column mark */
-
 void lpx_get_row_info(LPX *lp, int i, int *tagx, double *vx,
       double *dx);
 /* obtain row solution information */
@@ -1160,30 +1118,6 @@ void lpx_get_col_info(LPX *lp, int j, int *tagx, double *vx,
       double *dx);
 /* obtain column solution information */
 
-int lpx_get_ips_stat(LPX *lp);
-/* query status of interior point solution */
-
-void lpx_get_ips_row(LPX *lp, int i, double *vx, double *dx);
-/* obtain row interior point solution */
-
-void lpx_get_ips_col(LPX *lp, int j, double *vx, double *dx);
-/* obtain column interior point solution */
-
-double lpx_get_ips_obj(LPX *lp);
-/* obtain interior point value of the obj. function */
-
-int lpx_get_mip_stat(LPX *lp);
-/* query status of MIP solution */
-
-double lpx_get_mip_row(LPX *lp, int i);
-/* obtain row activity for MIP solution */
-
-double lpx_get_mip_col(LPX *lp, int j);
-/* obtain column activity for MIP solution */
-
-double lpx_get_mip_obj(LPX *lp);
-/* obtain value of the obj. func. for MIP solution */
-
 /* control parameters and statistics routines ------------------------*/
 
 void lpx_reset_parms(LPX *lp);
@@ -1217,6 +1151,9 @@ void lpx_std_basis(LPX *lp);
 void lpx_adv_basis(LPX *lp);
 /* construct advanced initial LP basis */
 
+void lpx_cpx_basis(LPX *lp);
+/* construct Bixby's initial LP basis */
+
 /* solver routines ---------------------------------------------------*/
 
 int lpx_simplex(LPX *lp);
@@ -1231,9 +1168,15 @@ int lpx_interior(LPX *lp);
 int lpx_integer(LPX *lp);
 /* easy-to-use driver to the branch-and-bound method */
 
+void lpx_check_int(LPX *lp, LPXKKT *kkt);
+/* check integer feasibility conditions */
+
 int lpx_intopt(LPX *mip);
 /* easy-to-use driver to the branch-and-bound method */
 
+int lpx_primal(LPX *lp);
+/* easy-to-use driver to the primal simplex method */
+
 /* LP basis and simplex table routines -------------------------------*/
 
 int lpx_invert(LPX *lp);
@@ -1274,6 +1217,45 @@ int lpx_dual_ratio_test(LPX *lp, int len, int ind[], double val[],
       int how, double tol);
 /* perform dual ratio test */
 
+/*--------------------------------------------------------------------*/
+
+int lpx_remove_tiny(int ne, int ia[], int ja[], double ar[],
+      double eps);
+/* remove zero and tiny elements */
+
+int lpx_reduce_form(LPX *lp, int len, int ind[], double val[],
+      double work[]);
+/* reduce linear form */
+
+double lpx_eval_row(LPX *lp, int len, int ind[], double val[]);
+/* compute explicitly specified row */
+
+double lpx_eval_degrad(LPX *lp, int len, int ind[], double val[],
+      int type, double rhs);
+/* compute degradation of the objective function */
+
+int lpx_gomory_cut(LPX *lp, int len, int ind[], double val[],
+      double work[]);
+/* generate Gomory's mixed integer cut */
+
+int lpx_cover_cut(LPX *lp, int len, int ind[], double val[],
+      double work[]);
+/* generate mixed cover cut */
+
+/*--------------------------------------------------------------------*/
+
+void *lpx_create_cog(LPX *lp);
+/* create the conflict graph */
+
+void lpx_add_cog_edge(void *cog, int i, int j);
+/* add edge to the conflict graph */
+
+int lpx_clique_cut(LPX *lp, void *cog, int ind[], double val[]);
+/* generate clique cut */
+
+void lpx_delete_cog(void *cog);
+/* delete the conflict graph */
+
 /* additional utility routines ---------------------------------------*/
 
 LPX *lpx_read_mps(char *fname);
