@@ -1,12 +1,12 @@
 /* glpluf.h (LU-factorization) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPLUF_H
@@ -38,6 +38,12 @@
 #define luf_solve             glp_luf_solve
 #define luf_delete            glp_luf_delete
 
+#define luf_v_sparse          glp_luf_v_sparse
+#define luf_vt_sparse         glp_luf_vt_sparse
+#define luf_f_sparse          glp_luf_f_sparse
+#define luf_ft_sparse         glp_luf_ft_sparse
+#define luf_sparse            glp_luf_sparse
+
 /*----------------------------------------------------------------------
 -- The structure LUF defines LU-factorization of a square matrix A,
 -- which is the following quartet:
@@ -220,6 +226,14 @@ struct LUF
       /* integer working array */
       double *work; /* double work[1+n]; */
       /* floating-point working array */
+      int *wpos; /* int wpos[1+n]; */
+      /* working array used by the routine luf_sparse */
+      /* WARNING: locations wpos[1], ..., wpos[n] must contain zeros
+                  all the time */
+      int *wcnt; /* int wcnt[1+n]; */
+      /* working array used by the routine luf_sparse */
+      int *wque; /* int wque[1+n]; */
+      /* working array used by the routine luf_sparse */
       /*--------------------------------------------------------------*/
       /* control parameters */
       int new_sva;
@@ -349,6 +363,21 @@ void luf_solve(LUF *luf, int tr, double x[]);
 void luf_delete(LUF *luf);
 /* delete LU-factorization */
 
+int luf_v_sparse(LUF *luf, int len, int ind[], double val[]);
+/* solve system V*x = b (sparse version) */
+
+int luf_vt_sparse(LUF *luf, int len, int ind[], double val[]);
+/* solve system V'*x = b (sparse version) */
+
+int luf_f_sparse(LUF *luf, int len, int ind[], double val[]);
+/* solve system F*x = b (sparse version) */
+
+int luf_ft_sparse(LUF *luf, int len, int ind[], double val[]);
+/* solve system F'*x = b (sparse version) */
+
+int luf_sparse(LUF *luf, int tr, int len, int ind[], double val[]);
+/* solve system A*x = b or A'*x = b (sparse version) */
+
 #endif
 
 /* eof */
