@@ -1,12 +1,12 @@
 /* glpspx.h (simplex method) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #ifndef _GLPSPX_H
@@ -103,30 +103,14 @@ struct SPX
          also may have non-zero objective coefficients) */
       /*--------------------------------------------------------------*/
       /* constraint matrix (has m rows and n columns) */
-#if 0
-      SPM *AA; /* SPM A[1:m,1:n]; */
-      /* constraint matrix (has m rows and n columns) */
-#endif
-#if 1
-      int *aa_ptr; /* int aa_ptr[1+m+n]; */
-      /* aa_ptr[0] is not used;
-         aa_ptr[i], 1 <= i <= m, is a pointer to the first element of
-         i-th row in the arrays aa_ind and aa_val;
-         aa_ptr[m+j], 1 <= j <= n, is a pointer to the first element of
-         j-th column in the arrays aa_ind and aa_val */
-      int *aa_len; /* int aa_len[1+m+n]; */
-      /* aa_len[0] is not used;
-         aa_len[i], 1 <= i <= m, is the number of (non-zero) elements
-         in i-th row;
-         aa_len[m+j], 1 <= j <= n, is the number of (non-zero) elements
-         in j-th column */
-      int *aa_ind; /* int aa_ind[1+nnz+nnz]; */
-      /* aa_ind[0] is not used;
-         aa_ind[*] are row and column indices of (non-zero) elements */
-      double *aa_val; /* double aa_val[1+nnz+nnz]; */
-      /* aa_val[0] is not used;
-         aa_val[*] are numerical values of (non-zero) elements */
-#endif
+      int *A_ptr; /* int A_ptr[1+m+1]; */
+      int *A_ind; /* int A_ind[A_ptr[m+1]]; */
+      double *A_val; /* double A_val[A_ptr[m+1]]; */
+      /* constraint matrix in storage-by-rows format */
+      int *AT_ptr; /* int AT_ptr[1+n+1]; */
+      int *AT_ind; /* int AT_ind[AT_ptr[n+1]]; */
+      double *AT_val; /* double AT_val[AT_ptr[n+1]]; */
+      /* constraint matrix in storage-by-columns format */
       /*--------------------------------------------------------------*/
       /* basic solution */
       int b_stat;
@@ -171,7 +155,7 @@ struct SPX
          variable xN[j], i.e. indx[m+j] = k means that posx[k] = m+j
          (if the current basis is undefined, contents of this array is
          undefined) */
-      INV *inv; /* INV inv[1:m,1:m]; */
+      BFI *inv; /* BFI inv[1:m,1:m]; */
       /* an invertable (factorized) form of the current basis matrix */
       double *bbar; /* double bbar[1+m]; */
       /* bbar[0] is not used;
