@@ -1,12 +1,12 @@
 /* glplpp1.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #include <float.h>
@@ -448,10 +448,14 @@ void lpp_load_orig(LPP *lpp, LPX *orig)
          resultant vector of objective coefficients is accumulated in
          the working array c */
       for (j = 1; j <= lpp->orig_n; j++)
-         c[j] = lpx_get_col_coef(orig, j);
+         c[j] = lpx_get_obj_coef(orig, j);
       for (i = 1; i <= lpp->orig_m; i++)
       {  /* obtain an objective coefficient at i-th row */
+#if 0
          temp = lpx_get_row_coef(orig, i);
+#else
+         temp = 0.0;
+#endif
          /* substitute i-th row into the objective function */
          if (temp != 0.0)
          {  len = lpx_get_mat_row(orig, i, ndx, val);
@@ -479,7 +483,7 @@ void lpp_load_orig(LPP *lpp, LPX *orig)
          lpp_add_col(lpp, lb, ub, c[j]);
       }
       /* copy the constant term of the original objective function */
-      lpp->c0 = lpx_get_obj_c0(orig);
+      lpp->c0 = lpx_get_obj_coef(orig, 0);
       /* if the original problem is maximization, change the sign of
          the objective function, because the transformed problem to be
          processed by the presolver must be minimization */
@@ -571,51 +575,10 @@ void *lpp_append_tqe(LPP *lpp, int type, int size)
 --
 -- The routine returns a pointer to the LP problem object. */
 
-struct load_info
-{     /* transit information passed to the routine next_aij */
-      LPP *lpp;
-      /* pointer to the LP presolver workspace */
-      LPPROW *row;
-      /* pointer to the current row */
-      LPPAIJ *aij;
-      /* pointer to the next element of the constraint matrix in the
-         current row */
-};
-
-static double next_aij(void *_info, int *i, int *j)
-{     /* "read" a next element of the constraint matrix */
-      struct load_info *info = _info;
-      double val;
-      while (info->aij == NULL)
-      {  /* either it is the first call or the current row has been
-            completely read; choose the first/next row */
-         if (info->row == NULL)
-            info->row = info->lpp->row_ptr;
-         else
-            info->row = info->row->next;
-         if (info->row == NULL)
-         {  /* the entire matrix has been completely read */
-            *i = *j = 0;
-            return 0.0;
-         }
-         /* set the pointer to the first element of the row */
-         info->aij = info->row->ptr;
-      }
-      /* obtain the next element from the current row */
-      *i = info->aij->row->i;
-      *j = info->aij->col->j;
-      val = info->aij->val;
-      /* advance the pointer */
-      info->aij = info->aij->r_next;
-      /* bring the next element to the calling program */
-      return val;
-}
-
 LPX *lpp_build_prob(LPP *lpp)
 {     LPX *prob;
       LPPROW *row;
       LPPCOL *col;
-      struct load_info info;
       int i, j, typx;
       /* count number of rows and columns in the resultant problem */
       lpp->m = lpp->n = 0;
@@ -631,7 +594,7 @@ LPX *lpp_build_prob(LPP *lpp)
          as the original problem */
       lpx_set_obj_dir(prob, lpp->orig_dir);
       /* set the constant term of the objective function */
-      lpx_set_obj_c0(prob,
+      lpx_set_obj_coef(prob, 0,
          lpp->orig_dir == LPX_MIN ? + lpp->c0 : - lpp->c0);
       /* create rows of the resultant problem */
       insist(lpp->m > 0);
@@ -671,15 +634,32 @@ LPX *lpp_build_prob(LPP *lpp)
          else
             typx = LPX_FX;
          lpx_set_col_bnds(prob, j, typx, col->lb, col->ub);
-         lpx_set_col_coef(prob, j,
+         lpx_set_obj_coef(prob, j,
             lpp->orig_dir == LPX_MIN ? + col->c : - col->c);
       }
       insist(col == NULL);
       /* create the constraint matrix of the resultant problem */
+#if 0
       info.lpp = lpp;
       info.row = NULL;
       info.aij = NULL;
       lpx_load_mat(prob, &info, next_aij);
+#else
+      {  LPPAIJ *aij;
+         int len, *ind;
+         double *val;
+         ind = ucalloc(1+lpp->n, sizeof(int));
+         val = ucalloc(1+lpp->n, sizeof(double));
+         for (row = lpp->row_ptr; row != NULL; row = row->next)
+         {  len = 0;
+            for (aij = row->ptr; aij != NULL; aij = aij->r_next)
+               len++, ind[len] = aij->col->j, val[len] = aij->val;
+            lpx_set_mat_row(prob, row->i, len, ind, val);
+         }
+         ufree(ind);
+         ufree(val);
+      }
+#endif
       /* count number of non-zeros in the resultant problem */
       lpp->nnz = lpx_get_num_nz(prob);
       /* internal data structures that represnts the resultant problem
