@@ -1,12 +1,12 @@
 /* glplpx2.c (problem retrieving routines) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #include <errno.h>
@@ -598,9 +598,6 @@ int lpx_is_b_avail(LPX *lp)
             avail = 0;
             break;
          case LPX_B_VALID:
-            insist(lp->b_inv != NULL);
-            insist(lp->b_inv->m == lp->m);
-            insist(lp->b_inv->valid);
             avail = 1;
             break;
          default:
@@ -688,18 +685,17 @@ int lpx_get_col_b_ind(LPX *lp, int j)
 -- *Synopsis*
 --
 -- #include "glplpx.h"
--- INV *lpx_access_inv(LPX *lp);
+-- BFI *lpx_access_inv(LPX *lp);
 --
 -- *Returns*
 --
 -- The routine lpx_access_inv returns a pointer to a factorization of
--- the basis matrix for the specified problem object. The factorization
--- may not exist, in which case the routine returns NULL.
+-- the basis matrix for the specified problem object.
 --
 -- NOTE: This routine is intended for internal use only. */
 
-INV *lpx_access_inv(LPX *lp)
-{     INV *b_inv;
+BFI *lpx_access_inv(LPX *lp)
+{     BFI *b_inv;
       b_inv = lp->b_inv;
       return b_inv;
 }
@@ -1264,42 +1260,6 @@ void lpx_get_col_bnds(LPX *lp, int j, int *typx, double *lb, double *ub)
       return;
 }
 
-double lpx_get_obj_c0(LPX *lp)
-{     /* obtain constant term of the obj. function */
-      return lpx_get_obj_coef(lp, 0);
-}
-
-double lpx_get_row_coef(LPX *lp, int i)
-{     /* obtain row objective coefficient */
-      if (!(1 <= i && i <= lpx_get_num_rows(lp)))
-         fault("lpx_get_row_coef: i = %d; row number out of range", i);
-      return 0.0;
-}
-
-double lpx_get_col_coef(LPX *lp, int j)
-{     /* obtain column objective coefficient */
-      if (!(1 <= j && j <= lpx_get_num_cols(lp)))
-         fault("lpx_get_col_coef: j = %d; column number out of range",
-            j);
-      return lpx_get_obj_coef(lp, j);
-}
-
-int lpx_get_row_mark(LPX *lp, int i)
-{     /* determine row mark */
-      insist(lp == lp);
-      insist(i == i);
-      fault("lpx_get_row_mark: no more supported");
-      return 0;
-}
-
-int lpx_get_col_mark(LPX *lp, int j)
-{     /* determine column mark */
-      insist(lp == lp);
-      insist(j == j);
-      fault("lpx_get_col_mark: no more supported");
-      return 0;
-}
-
 void lpx_get_row_info(LPX *lp, int i, int *tagx, double *vx, double *dx)
 {     /* obtain row solution information */
       if (tagx != NULL) *tagx = lpx_get_row_stat(lp, i);
@@ -1316,48 +1276,4 @@ void lpx_get_col_info(LPX *lp, int j, int *tagx, double *vx, double *dx)
       return;
 }
 
-int lpx_get_ips_stat(LPX *lp)
-{     /* query status of interior-point solution */
-      return lpx_ipt_status(lp);
-}
-
-void lpx_get_ips_row(LPX *lp, int i, double *vx, double *dx)
-{     /* obtain row interior point solution */
-      if (vx != NULL) *vx = lpx_ipt_row_prim(lp, i);
-      if (dx != NULL) *dx = lpx_ipt_row_dual(lp, i);
-      return;
-}
-
-void lpx_get_ips_col(LPX *lp, int j, double *vx, double *dx)
-{     /* obtain column interior point solution */
-      if (vx != NULL) *vx = lpx_ipt_col_prim(lp, j);
-      if (dx != NULL) *dx = lpx_ipt_col_dual(lp, j);
-      return;
-}
-
-double lpx_get_ips_obj(LPX *lp)
-{     /* obtain interior point value of the obj. function */
-      return lpx_ipt_obj_val(lp);
-}
-
-int lpx_get_mip_stat(LPX *lp)
-{     /* query status of mip solution */
-      return lpx_mip_status(lp);
-}
-
-double lpx_get_mip_row(LPX *lp, int i)
-{     /* obtain row activity for MIP solution */
-      return lpx_mip_row_val(lp, i);
-}
-
-double lpx_get_mip_col(LPX *lp, int j)
-{     /* obtain column activity for MIP solution */
-      return lpx_mip_col_val(lp, j);
-}
-
-double lpx_get_mip_obj(LPX *lp)
-{     /* obtain value of the obj. func. for MIP solution */
-      return lpx_mip_obj_val(lp);
-}
-
 /* eof */
