@@ -1,13 +1,13 @@
 /* glplpx8b.c (bounds sensitivity analysis routine) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
--- Department for Applied Informatics, Moscow Aviation Institute,
--- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
+-- This code is part of GNU Linear Programming Kit (GLPK).
 --
 -- Author: Brady Hunsaker <bkh@member.fsf.org>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
+-- Department for Applied Informatics, Moscow Aviation Institute,
+-- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #include <float.h>
@@ -190,7 +190,7 @@ int lpx_print_sens_bnds(LPX *lp, char *fname)
                   tagx == LPX_NF ? "NF" :
                   tagx == LPX_NS ? "NS" : "??");
                /* objective coefficient */
-               fprintf(fp, "%13.6g ", lpx_get_col_coef(lp, j) );
+               fprintf(fp, "%13.6g ", lpx_get_obj_coef(lp, j));
                if (tagx == LPX_NL)
                {  if (dir==LPX_MIN)
                   {  /* reduced cost must be positive */
