@@ -1,12 +1,12 @@
 /* glpluf.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #include <float.h>
@@ -131,6 +131,10 @@ LUF *luf_create(int n, int sv_size)
       /* allocate working arrays */
       luf->flag = ucalloc(1+n, sizeof(int));
       luf->work = ucalloc(1+n, sizeof(double));
+      luf->wpos = ucalloc(1+n, sizeof(int));
+      for (i = 1; i <= n; i++) luf->wpos[i] = 0;
+      luf->wcnt = ucalloc(1+n, sizeof(int));
+      luf->wque = ucalloc(1+n, sizeof(int));
       /* set default values of control parameters */
       luf->new_sva = 0;
       luf->piv_tol = 0.10;
@@ -1875,6 +1879,9 @@ void luf_delete(LUF *luf)
       ufree(luf->sv_next);
       ufree(luf->flag);
       ufree(luf->work);
+      ufree(luf->wpos);
+      ufree(luf->wcnt);
+      ufree(luf->wque);
       ufree(luf);
       return;
 }
