@@ -1,12 +1,12 @@
 /* glpmpl4.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #include <ctype.h>
@@ -576,6 +576,10 @@ MPL *mpl_initialize(void)
       mpl->out_file = NULL;
       mpl->out_buf = NULL;
       mpl->out_cnt = 0;
+#if 1 /* 14/VII-2006 */
+      mpl->prt_fp = NULL;
+      mpl->prt_file = NULL;
+#endif
       /* solver interface segment */
       if (setjmp(mpl->jump)) insist(mpl != mpl);
       mpl->phase = 0;
@@ -980,6 +984,7 @@ int mpl_get_row_bnds(MPL *mpl, int i, double *_lb, double *_ub)
       if (!(1 <= i && i <= mpl->m))
          fault("mpl_get_row_bnds: i = %d; row number out of range", i);
       con = mpl->row[i];
+#if 0 /* 21/VII-2006 */
       if (con->con->lbnd == NULL && con->con->ubnd == NULL)
          type = MPL_FR, lb = ub = 0.0;
       else if (con->con->ubnd == NULL)
@@ -990,6 +995,20 @@ int mpl_get_row_bnds(MPL *mpl, int i, double *_lb, double *_ub)
          type = MPL_DB, lb = con->lbnd, ub = con->ubnd;
       else
          type = MPL_FX, lb = ub = con->lbnd;
+#else
+      lb = (con->con->lbnd == NULL ? -DBL_MAX : con->lbnd);
+      ub = (con->con->ubnd == NULL ? +DBL_MAX : con->ubnd);
+      if (lb == -DBL_MAX && ub == +DBL_MAX)
+         type = MPL_FR, lb = ub = 0.0;
+      else if (ub == +DBL_MAX)
+         type = MPL_LO, ub = 0.0;
+      else if (lb == -DBL_MAX)
+         type = MPL_UP, lb = 0.0;
+      else if (con->con->lbnd != con->con->ubnd)
+         type = MPL_DB;
+      else
+         type = MPL_FX;
+#endif
       if (_lb != NULL) *_lb = lb;
       if (_ub != NULL) *_ub = ub;
       return type;
@@ -1199,6 +1218,7 @@ int mpl_get_col_bnds(MPL *mpl, int j, double *_lb, double *_ub)
          fault("mpl_get_col_bnds: j = %d; column number out of range",
             j);
       var = mpl->col[j];
+#if 0 /* 21/VII-2006 */
       if (var->var->lbnd == NULL && var->var->ubnd == NULL)
          type = MPL_FR, lb = ub = 0.0;
       else if (var->var->ubnd == NULL)
@@ -1209,6 +1229,20 @@ int mpl_get_col_bnds(MPL *mpl, int j, double *_lb, double *_ub)
          type = MPL_DB, lb = var->lbnd, ub = var->ubnd;
       else
          type = MPL_FX, lb = ub = var->lbnd;
+#else
+      lb = (var->var->lbnd == NULL ? -DBL_MAX : var->lbnd);
+      ub = (var->var->ubnd == NULL ? +DBL_MAX : var->ubnd);
+      if (lb == -DBL_MAX && ub == +DBL_MAX)
+         type = MPL_FR, lb = ub = 0.0;
+      else if (ub == +DBL_MAX)
+         type = MPL_LO, ub = 0.0;
+      else if (lb == -DBL_MAX)
+         type = MPL_UP, lb = 0.0;
+      else if (var->var->lbnd != var->var->ubnd)
+         type = MPL_DB;
+      else
+         type = MPL_FX;
+#endif
       if (_lb != NULL) *_lb = lb;
       if (_ub != NULL) *_ub = ub;
       return type;
@@ -1357,6 +1391,10 @@ void mpl_terminate(MPL *mpl)
          ufclose(mpl->out_fp);
       if (mpl->out_file != NULL) ufree(mpl->out_file);
       if (mpl->out_buf != NULL) ufree(mpl->out_buf);
+#if 1 /* 14/VII-2006 */
+      if (mpl->prt_fp != NULL) ufclose(mpl->prt_fp);
+      if (mpl->prt_file != NULL) ufree(mpl->prt_file);
+#endif
       if (mpl->mod_file != NULL) ufree(mpl->mod_file);
       ufree(mpl->mpl_buf);
       ufree(mpl);
