@@ -1,12 +1,12 @@
 /* glpspx1.c (simplex method generic routines) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Andrew Makhorin,
+-- This code is part of GNU Linear Programming Kit (GLPK).
+--
+-- Copyright (C) 2000, 01, 02, 03, 04, 05, 06 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
--- This file is part of GLPK (GNU Linear Programming Kit).
---
 -- GLPK is free software; you can redistribute it and/or modify it
 -- under the terms of the GNU General Public License as published by
 -- the Free Software Foundation; either version 2, or (at your option)
@@ -19,8 +19,8 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with GLPK; see the file COPYING. If not, write to the Free
--- Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
--- 02111-1307, USA.
+-- Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+-- 02110-1301, USA.
 ----------------------------------------------------------------------*/
 
 #include <float.h>
@@ -89,26 +89,9 @@ static int inv_col(void *info, int j, int rn[], double bj[])
 }
 
 int spx_invert(SPX *spx)
-{     static double piv_tol[1+3] = { 0.00, 0.10, 0.30, 0.70 };
-      int try, ret;
-      /* if the invertable form has a wrong size, delete it */
-      if (spx->inv != NULL && spx->inv->m != spx->m)
-         inv_delete(spx->inv), spx->inv = NULL;
-      /* if the invertable form does not exist, create it */
-#if 0
-      if (spx->inv == NULL) spx->inv = inv_create(spx->m, 100);
-#else
-      if (spx->inv == NULL) spx->inv = inv_create(spx->m, 50);
-#endif
+{     int ret;
       /* try to factorize the basis matrix */
-      for (try = 1; try <= 3; try++)
-      {  if (try > 1 && spx->msg_lev >= 3)
-            print("spx_invert: trying to factorize the basis using thre"
-               "shold tolerance %g", piv_tol[try]);
-         spx->inv->luf->piv_tol = piv_tol[try];
-         ret = inv_decomp(spx->inv, spx, inv_col);
-         if (ret == 0) break;
-      }
+      ret = bfi_factorize(spx->inv, spx->m, spx, inv_col);
       /* analyze the return code */
       switch (ret)
       {  case 0:
@@ -166,7 +149,7 @@ int spx_invert(SPX *spx)
 
 void spx_ftran(SPX *spx, double x[], int save)
 {     insist(spx->b_stat == LPX_B_VALID);
-      inv_ftran(spx->inv, x, save);
+      bfi_ftran_dense(spx->inv, x, save);
       return;
 }
 
@@ -195,7 +178,7 @@ void spx_ftran(SPX *spx, double x[], int save)
 
 void spx_btran(SPX *spx, double x[])
 {     insist(spx->b_stat == LPX_B_VALID);
-      inv_btran(spx->inv, x);
+      bfi_btran_dense(spx->inv, x);
       return;
 }
 
@@ -227,7 +210,7 @@ void spx_btran(SPX *spx, double x[])
 int spx_update(SPX *spx, int j)
 {     int ret;
       insist(1 <= j && j <= spx->m);
-      ret = inv_update(spx->inv, j);
+      ret = bfi_update_binv(spx->inv, j);
       return ret;
 }
 
